pub fn change_datapublisherconfig(
cfg: &DataPublisherConfig,
) -> Option<TofCommand>Expand description
Change the data publisher config part of the config file
pub fn change_datapublisherconfig(
cfg: &DataPublisherConfig,
) -> Option<TofCommand>Change the data publisher config part of the config file