pub struct TofCommand {
pub command_code: TofCommandCode,
pub payload: Vec<u8>,
}Expand description
A general command class with an arbitrary payload
Since the commands should in general be small the maixmal payload size is limited to 256 bytes
All commands will get broadcasted and the receiver has to figure out if they have to rect to that command
Fields
command_code: TofCommandCodepayload: Vec<u8>Implementations
Sourceimpl TofCommand
impl TofCommand
pub fn new() -> Self
Sourcepub fn forge_changerunconfig(key_value: &Vec<String>) -> Self
pub fn forge_changerunconfig(key_value: &Vec<String>) -> Self
In case the command is supposed to change the next run configuration we can create it with this function
Arguments
- key_value : a list of keys and a single value (last item of the list
Sourcepub fn extract_changerunconfig(&self) -> Option<Vec<String>>
pub fn extract_changerunconfig(&self) -> Option<Vec<String>>
After the command has been unpackt, reconstruct the key/value string